
------------------------------------------------------------------------
--  IBM*                                                                  
--  Licensed Materials - Property of IBM                                  
--  5765-F38                                                              
--  (C) Copyright IBM Corporation 2001,2003                               
--  All rights reserved.                                                  
--                                                                        
-- * Trademark of International Business Machines                         
------------------------------------------------------------------------

--**********************************************************************
--**********************************************************************
--**
--**  Product Name:      DB2 Net Search Extender
--**
--**  Source File Name:  ctecview.ddl     
--**
--**  Description:       The following script is executed
--**                     when a database is enabled for text.
--**
--**  Status:            Version 8.1.2
--**
--**********************************************************************
--**********************************************************************

--*---------------------------------------------------------------------
--* create administration view(s) per index (used for design documentation)
--*---------------------------------------------------------------------
-- CREATE VIEW
-- DB2EXT.EVENTIX123456
--   ( PK01,
--     OPERATION,
--     TIME,
--     REASON,
--     MESSAGE
--   )
-- AS
--    SELECT  "PK01",
--            "OPERATION",
--            "TIME",
--            "SEVERITY",
--            "REASON",
--            "MESSAGE"
--    FROM  DB2EXT."TEVENTIX123456";
--
--*---------------------------------------------------------------------
--* create administration view(s)
--*---------------------------------------------------------------------
CREATE VIEW DB2EXT.DBDEFAULTS
       ( DEFAULTNAME,
         DEFAULTVALUE
       )
   AS
      SELECT  "NAME",
              "VALUE"
      FROM  DB2EXT."TDBDEFAULTS" WHERE "TYPE" > 0;

------------------------------------------------------------------------
-- NEW PROPOSAL:
-- view db2ext.textindexes
-- view db2ext.textindexcolumns 
-- view db2text.textindexformats
-- view db2text.indexconfiguration
-- no view formats, models any more (deprecated)
------------------------------------------------------------------------

CREATE VIEW DB2EXT.TEXTINDEXFORMATS
       ( INDSCHEMA,
         INDNAME,  
         FORMAT,
         MODELNAME,
         MODELFILE,
         MODELCCSID,
         DEFAULT
       )
	AS SELECT TI."INDEXSCHEMA",
             TI."INDEXNAME",
             TF."SOURCENAME",
             TM."MODELNAME",	
             TM."MODELFILE",
             TM."CCSID",
             CASE
               WHEN TM."MODELNUMBER" = 0
               THEN 1 
               ELSE 0
             END
      FROM  DB2EXT."TTEXTINDEXES"  TI,
            DB2EXT."TMODELS"       TM,
            DB2EXT."TFORMATS"      TF

      WHERE TI."INDEXIDENTIFIER" = TM."INDEXIDENTIFIER" AND
            TF."SOURCEIDENTIFIER"= TM."FORMATIDENTIFIER"

      UNION ALL

	   SELECT TI."INDEXSCHEMA",
             TI."INDEXNAME",
             TF."SOURCENAME",
             CAST (NULL AS VARCHAR(30)),
             CAST (NULL AS VARCHAR(256)),
             CAST (NULL AS INTEGER),
             1
      FROM  DB2EXT."TTEXTINDEXES"  TI,
            DB2EXT."TTEXTCOLUMNS"  TC,
            DB2EXT."TFORMATS"      TF

      WHERE TI."INDEXIDENTIFIER" = TC."INDEXIDENTIFIER" AND
            TF."SOURCEIDENTIFIER"= TC."FORMAT" AND
            NOT EXISTS(SELECT 1 FROM DB2EXT."TMODELS" TM
                       WHERE TI."INDEXIDENTIFIER" = TM."INDEXIDENTIFIER")
;
             	
------------------------------------------------------------------------               

CREATE VIEW DB2EXT.TEXTINDEXES
       ( INDSCHEMA,
         INDNAME,
         TABSCHEMA, 
         TABNAME,
         COLNAME, 
         CCSID, 
         LANGUAGE, 
         FUNCTIONSCHEMA,
         FUNCTIONNAME,
         INDEXDIRECTORY, 
         WORKDIRECTORY,
         CACHEDIRECTORY,
         UPDATEFREQUENCY, 
         UPDATEMINIMUM,
         EVENTVIEWSCHEMA,
         EVENTVIEWNAME,
         LOGVIEWSCHEMA, 
         LOGVIEWNAME,
         COMMITCOUNT,
         NUMBER_DOCS,
         REORG_SUGGESTED,
         REORGAUTOMATIC,
         RECREATEONUPDATE,
         CREATIONTIME,
         UPDATETIME,
         PERSISTENTCACHE,
         MAXIMUMCACHESIZE,
         PCTFREE,	
         CACHETABLE,
         RESULTORDER,
         ATTRIBUTES,
         VIEWKEYCOLUMNS
       )

 AS SELECT TI."INDEXSCHEMA",
           TI."INDEXNAME",
           TC."ALIASSCHEMA",
           TC."ALIASNAME",
           TC."COLUMNNAME",
           TC."CCSID",
           TC."LANGUAGE",
           TC."FUNCTIONSCHEMA",
           TC."FUNCTIONNAME",
           TI."INDEXDIRECTORY",
           TI."WORKDIRECTORY",
           TI."CACHEDIRECTORY",
           TI."UPDATEFREQUENCY",
           TI."UPDATEMINIMUM",
           TI."EVENTVIEWSCHEMA",
           TI."EVENTVIEWNAME",
           TI."LOGVIEWSCHEMA",
           TI."LOGVIEWNAME",
           TI."COMMITCOUNT",
           DB2EXT.NUMBER_DOCS(TC."INDEXIDENTIFIER",TC."INDEXPROPERTIES"),
           DB2EXT.REORG_SUGGESTED(TC."INDEXIDENTIFIER",TC."INDEXPROPERTIES"),
           TI."REORGANIZATIONMODE",
           CASE WHEN TI."LOGVIEWNAME" IS NULL THEN 1 ELSE 0 END,
           TI."CREATIONTIME",
           TI."UPDATETIME",
           CASE TI."CACHEOPTION" WHEN 1 
                THEN CASE WHEN ti."CACHEDIRECTORY" IS NULL THEN 0 ELSE 1 END
                ELSE NULL
           END,   
           TI."CACHEMAXIMUM",
           TI."CACHEFREE",
           DB2EXT.RESULTEXPR("EXPRESSIONLISTS"),
           DB2EXT.ORDEREXPR("EXPRESSIONLISTS"),
           DB2EXT.ATTRIBUTEEXPR("EXPRESSIONLISTS"),
           DB2EXT.VIEWKEYCOLUMNS("EXPRESSIONLISTS")

      FROM  DB2EXT."TTEXTCOLUMNS"  TC,
            DB2EXT."TTEXTINDEXES"  TI
      WHERE TC."INDEXIDENTIFIER" = TI."INDEXIDENTIFIER"
;

--------------------------------------------------------------------------------

CREATE VIEW DB2EXT.INDEXCONFIGURATION
       ( INDSCHEMA,
         INDNAME,  
         PARAMETER,
         VALUE
       )
	AS SELECT TI."INDEXSCHEMA",
             TI."INDEXNAME",
             TC."PARAMETER",
             TC."VALUE"
      FROM  DB2EXT."TCONFIGURATION" TC,
            DB2EXT."TTEXTINDEXES"   TI
      WHERE TC."INDEXIDENTIFIER" = TI."INDEXIDENTIFIER"    
;

--*---------------------------------------------------------------------
--* grant privilege(s) on administration view(s) to public
--*---------------------------------------------------------------------
GRANT SELECT ON TABLE  DB2EXT.DBDEFAULTS         TO PUBLIC;
GRANT SELECT ON TABLE  DB2EXT.TEXTINDEXES        TO PUBLIC;
GRANT SELECT ON TABLE  DB2EXT.TEXTINDEXFORMATS   TO PUBLIC;
GRANT SELECT ON TABLE  DB2EXT.INDEXCONFIGURATION TO PUBLIC;

--*---------------------------------------------------------------------
--* backward compatibility view(s)
--*---------------------------------------------------------------------
CREATE VIEW DB2EXT.FORMATS
       ( FORMATNAME,
         FUNCTIONSCHEMA,
         FUNCTIONNAME
       )
   AS
      SELECT  "SOURCENAME",
              "FUNCTIONSCHEMA",
              "FUNCTIONNAME"
      FROM  DB2EXT."TFORMATS";

------------------------------------------------------------------------

CREATE VIEW DB2EXT.MODELS
       ( INDEXSCHEMA,
         INDEXNAME,
         MODELNAME,
         FORMAT
--       DEFAULT
       )
   AS
      SELECT  TX."INDEXSCHEMA",
              TX."INDEXNAME",
              DM."MODELNAME",
--            DB2EXT.FORMAT(DM."FORMATIDENTIFIER")
              DF."SOURCENAME"
--            CASE
--               WHEN DM."MODELNUMBER" = 0
--               THEN 'YES' 
--               ELSE 'NO'
--            END
      FROM  DB2EXT."TTEXTINDEXES"  TX,
            DB2EXT."TMODELS"       DM,
            DB2EXT."TFORMATS"      DF

      WHERE TX."INDEXIDENTIFIER" = DM."INDEXIDENTIFIER"
      AND   DF."SOURCEIDENTIFIER" = DM."FORMATIDENTIFIER";

------------------------------------------------------------------------

CREATE VIEW DB2EXT.TEXTCOLUMNS
       ( INDEXSCHEMA, INDEXNAME,
         TABLESCHEMA, TABLENAME,
         COLUMN,
         CCSID, LANGUAGE, FORMAT,
         MODELFILE,
         FUNCTIONSCHEMA, FUNCTIONNAME,
         INDEXDIRECTORY, WORKDIRECTORY,
         UPDATEFREQUENCY, UPDATEMINIMUM,
         EVENTVIEWSCHEMA, EVENTVIEWNAME,
         COMMITCOUNT,
         OPERATION,
         OPERATIONBEGIN,
         OPERATIONEND,
         NUMBER_DOCS,
         REORG_SUGGESTED
       )
   AS WITH
           INDEXDATA ( "INDEXIDENTIFIER",
                       "FORMATIDENTIFIER",
                       "INDEXSCHEMA",     
                       "INDEXNAME",       
                       "TABLESCHEMA",     
                       "TABLENAME",       
                       "COLUMNNAME",      
                       "CCSID",           
                       "LANGUAGE",        
                       "FORMAT",          
                       "FUNCTIONSCHEMA",  
                       "FUNCTIONNAME",    
                       "INDEXDIRECTORY",  
                       "WORKDIRECTORY",   
                       "UPDATEFREQUENCY", 
                       "UPDATEMINIMUM",   
                       "EVENTVIEWSCHEMA",   
                       "EVENTVIEWNAME",     
                       "COMMITCOUNT",
                       "OPERATION",
                       "OPERATIONBEGIN",  
                       "OPERATIONEND", 
                       "INDEXCOUNT",    
                       "REORGANIZATION"   
                     )
         AS (SELECT TC."INDEXIDENTIFIER",
                    TC."FORMAT",
                    TI."INDEXSCHEMA",
                    TI."INDEXNAME",
                    TC."ALIASSCHEMA",
                    TC."ALIASNAME",
                    TC."COLUMNNAME",
                    TC."CCSID",
                    TC."LANGUAGE",
                    TF."SOURCENAME",
                    TC."FUNCTIONSCHEMA",
                    TC."FUNCTIONNAME",
                    TI."INDEXDIRECTORY",
                    TI."WORKDIRECTORY",
                    TI."UPDATEFREQUENCY",
                    TI."UPDATEMINIMUM",
                    TI."EVENTTABLESCHEMA",
                    SUBSTR(TI."EVENTTABLENAME",2),
                    TI."COMMITCOUNT",
                    CAST('UNKNOWN' AS VARCHAR(256)),
                    CAST(NULL AS TIMESTAMP),
                    CAST(NULL AS TIMESTAMP),
                    DB2EXT.NUMBER_DOCS(TC."INDEXIDENTIFIER",TC."INDEXPROPERTIES"),
                    DB2EXT.REORG_SUGGESTED(TC."INDEXIDENTIFIER",TC."INDEXPROPERTIES")
              FROM  DB2EXT."TTEXTCOLUMNS"  TC,
                    DB2EXT."TTEXTINDEXES"  TI,
                    DB2EXT."TFORMATS"      TF 
              WHERE TF."SOURCEIDENTIFIER" = TC."FORMAT" AND
                    TC."INDEXIDENTIFIER" = TI."INDEXIDENTIFIER"
            ),

           MODELINFO ("INDEXIDENTIFIER",
                      "FORMATIDENTIFIER",
                      "MODELFILE"
                     )
         AS ( SELECT  XD."INDEXIDENTIFIER",
                      XD."FORMATIDENTIFIER",
                      DM."MODELFILE"

              FROM  INDEXDATA            XD,
                    DB2EXT."TMODELS"     DM

              WHERE DM."INDEXIDENTIFIER" = XD."INDEXIDENTIFIER"
              AND   DM."FORMATIDENTIFIER" = XD."FORMATIDENTIFIER"
            ),
           NULLINFO  ("INDEXIDENTIFIER",
                      "FORMATIDENTIFIER"
                     )
         AS ( SELECT  XD."INDEXIDENTIFIER",
                      XD."FORMATIDENTIFIER"

              FROM  INDEXDATA            XD

              EXCEPT ALL
      
              SELECT  MI."INDEXIDENTIFIER",
                      MI."FORMATIDENTIFIER"   

              FROM  MODELINFO            MI
            )
            
      SELECT  XD."INDEXSCHEMA",
              XD."INDEXNAME",
              XD."TABLESCHEMA",
              XD."TABLENAME",
              XD."COLUMNNAME",
              XD."CCSID",
              XD."LANGUAGE",
              XD."FORMAT",
              MI."MODELFILE",
              XD."FUNCTIONSCHEMA",
              XD."FUNCTIONNAME",
              XD."INDEXDIRECTORY",
              XD."WORKDIRECTORY",
              XD."UPDATEFREQUENCY",
              XD."UPDATEMINIMUM",
              XD."EVENTVIEWSCHEMA",
              XD."EVENTVIEWNAME",
              XD."COMMITCOUNT",
              XD."OPERATION",
              XD."OPERATIONBEGIN",
              XD."OPERATIONEND",
              XD."INDEXCOUNT",
              XD."REORGANIZATION"

      FROM  INDEXDATA            XD,
            MODELINFO            MI

      WHERE XD."INDEXIDENTIFIER" = MI."INDEXIDENTIFIER"
      AND   XD."FORMATIDENTIFIER" = MI."FORMATIDENTIFIER"
      
      UNION ALL
      
      SELECT  XD."INDEXSCHEMA",
              XD."INDEXNAME",
              XD."TABLESCHEMA",
              XD."TABLENAME",
              XD."COLUMNNAME",
              XD."CCSID",
              XD."LANGUAGE",
              XD."FORMAT",
              CAST (NULL AS VARCHAR(254)),
              XD."FUNCTIONSCHEMA",
              XD."FUNCTIONNAME",
              XD."INDEXDIRECTORY",
              XD."WORKDIRECTORY",
              XD."UPDATEFREQUENCY",
              XD."UPDATEMINIMUM",
              XD."EVENTVIEWSCHEMA",
              XD."EVENTVIEWNAME",
              XD."COMMITCOUNT",
              XD."OPERATION",
              XD."OPERATIONBEGIN",
              XD."OPERATIONEND",
              XD."INDEXCOUNT",
              XD."REORGANIZATION"

      FROM  INDEXDATA            XD,
            NULLINFO             NI

      WHERE XD."INDEXIDENTIFIER" = NI."INDEXIDENTIFIER"
      AND   XD."FORMATIDENTIFIER" = NI."FORMATIDENTIFIER";

--*---------------------------------------------------------------------
--* grant privilege(s) on administration view(s) to public (BACKWARD CO)
--*---------------------------------------------------------------------
GRANT SELECT ON TABLE  DB2EXT.TEXTCOLUMNS        TO PUBLIC;
GRANT SELECT ON TABLE  DB2EXT.FORMATS            TO PUBLIC;
GRANT SELECT ON TABLE  DB2EXT.MODELS             TO PUBLIC;

------------------------------------------------------------------------

