
------------------------------------------------------------------------
--  IBM*                                                                  
--  Licensed Materials - Property of IBM                                  
--  5765-F38                                                              
--  (C) Copyright IBM Corporation 2001,2003                               
--  All rights reserved.                                                  
--                                                                        
-- * Trademark of International Business Machines                         
------------------------------------------------------------------------

--**********************************************************************
--**********************************************************************
--**
--**  Product Name:      DB2 Net Search Extender
--**
--**  Source File Name:  ctedlcud.ddl
--**
--**  Function:          Declaration of all DataLink UDFs for DB2Extender
--**
--**  Status:            Version 8.1.2
--**
--**********************************************************************
--**********************************************************************

--*---------------------------------------------------------------------
-- internal used function
--*---------------------------------------------------------------------

   CREATE FUNCTION DB2EXT.GETDATALINKCONTENT( 
                                             DLURLSCHEME    VARCHAR(20), 
                                             DLURLSERVER    VARCHAR(254), 
                                             DLURLPATH      VARCHAR(254),
                                             DLURLCOMPLETE  VARCHAR(254),
                                             PROXYHOST      VARCHAR(254), 
                                             PROXYPORT      VARCHAR(6), 
                                             PROXYTYPE      VARCHAR(10), 
                                             TIMEOUT        INTEGER 
                                            ) 
   RETURNS BLOB(100K) 
   SPECIFIC DATALINKCONTENT3 
   EXTERNAL NAME 'DataLinkUDF.getDLBinary' 
   LANGUAGE JAVA 
   PARAMETER STYLE DB2GENERAL 
   NOT DETERMINISTIC 
   NULL CALL 
   NO SQL 
   NO EXTERNAL ACTION 
   ALLOW PARALLEL 

   FENCED
 
   NO SCRATCHPAD 
   NO FINAL CALL;

--*---------------------------------------------------------------------
-- external used function
--*---------------------------------------------------------------------
------------------------------------------------------------------------
-- Function name:	getDataLinkContent
-- Parameter:		DATALINK --> a datalink value 
-- Return value:	BLOB
------------------------------------------------------------------------

   CREATE FUNCTION DB2EXT.GETDATALINKCONTENT( 
                                             DATALINKVALUE DATALINK 
                                            ) 
   RETURNS BLOB(100K) 
   SPECIFIC DATALINKCONTENT1 
   NOT DETERMINISTIC 
   NO EXTERNAL ACTION 
   LANGUAGE SQL 
   READS SQL DATA 

   RETURN 
      WITH TEMPTABLE (PROXYHOST, PROXYPORT, PROXYTYPE, PROXYTIMEOUT) 
      AS (
          SELECT '' AS PROXYHOST, '' AS PROXYPORT, 'PROXY' AS PROXYTYPE, 
                 0 AS PROXYTIMEOUT	
          FROM (SELECT COUNT(*) AS NUMBER FROM DB2EXT.PROXYINFORMATION
               ) AS COUNTROW
          WHERE COUNTROW.NUMBER = 0
          UNION
          SELECT PROXYHOST, PROXYPORT, PROXYTYPE, PROXYTIMEOUT
          FROM DB2EXT.PROXYINFORMATION
         )
      SELECT DB2EXT.GETDATALINKCONTENT(SYSIBM.DLURLSCHEME(DATALINKVALUE),
                                       SYSIBM.DLURLSERVER(DATALINKVALUE),

------------------------------------------------------------------------
-- Change this parameter to:
-- SYSIBM.dlurlpathonly(dataLinkValue)
-- as long as DataLink behaviour is not changed
                                       SYSIBM.DLURLPATH(DATALINKVALUE),
------------------------------------------------------------------------
                                       SYSIBM.DLURLCOMPLETE(DATALINKVALUE),
                                       TT.PROXYHOST,
                                       TT.PROXYPORT,
                                       TT.PROXYTYPE,
                                       TT.PROXYTIMEOUT
                                      )
      FROM TEMPTABLE TT;
	
------------------------------------------------------------------------
-- Function name:	getDataLinkContent
-- Parameter:		DATALINK --> a datalink value 
--			INTEGER  --> connect timeout value in seconds
-- Return value:	BLOB
------------------------------------------------------------------------

   CREATE FUNCTION DB2EXT.GETDATALINKCONTENT( 
                                             DATALINKVALUE  DATALINK, 
                                             TIMEOUT        INTEGER 
                                            ) 
    RETURNS BLOB(100K)
    SPECIFIC DATALINKCONTENT2 
    NOT DETERMINISTIC 
    NO EXTERNAL ACTION 
    LANGUAGE SQL 
    READS SQL DATA 

    RETURN 
	WITH TEMPTABLE(PROXYHOST, PROXYPORT, PROXYTYPE, PROXYTIMEOUT) 
	AS (
		SELECT '' AS PROXYHOST, '' AS PROXYPORT, 'PROXY' AS PROXYTYPE, 
			0 AS PROXYTIMEOUT	
		FROM (SELECT COUNT(*) AS NUMBER FROM DB2EXT.PROXYINFORMATION)
		     AS COUNTROW
		WHERE COUNTROW.NUMBER = 0
		UNION
		SELECT PROXYHOST, PROXYPORT, PROXYTYPE, PROXYTIMEOUT
		FROM   DB2EXT.PROXYINFORMATION)
	SELECT DB2EXT.GETDATALINKCONTENT(SYSIBM.DLURLSCHEME(DATALINKVALUE),
					 SYSIBM.DLURLSERVER(DATALINKVALUE),
------------------------------------------------------------------------
-- Change this parameter to:
-- SYSIBM.dlurlpathonly(dataLinkValue)
-- as long as DataLink behaviour is not changed
					 SYSIBM.DLURLPATH(DATALINKVALUE),
------------------------------------------------------------------------
					 SYSIBM.DLURLCOMPLETE(DATALINKVALUE),
					 TT.PROXYHOST,
					 TT.PROXYPORT,
					 TT.PROXYTYPE,
					 TIMEOUT
					)
	FROM TEMPTABLE TT;

------------------------------------------------------------------------

------------------------------------------------------------------------
-- Function name:	getDataLinkContent
-- Parameter:		DATALINK   --> a datalink value 
--			INTEGER    --> connection timeout value in seconds
--			VARCHAR(7) --> if value equal to 'NOPROXY' than
--				       the entry in the table 
--				       db2ext.proxyInformation will be
--	                               ignored 
-- Return value:	BLOB
------------------------------------------------------------------------

   CREATE FUNCTION DB2EXT.GETDATALINKCONTENT( 
                                             DATALINKVALUE  DATALINK, 
                                             TIMEOUT        INTEGER,
					     NOPROXY        VARCHAR(7)
                                            ) 
    RETURNS BLOB(100K)
    SPECIFIC DATALINKCONTENT4
    NOT DETERMINISTIC 
    NO EXTERNAL ACTION 
    LANGUAGE SQL 
    READS SQL DATA 

    RETURN 
	WITH TEMPTABLE(PROXYHOST, PROXYPORT, PROXYTYPE, PROXYTIMEOUT) 
	AS (
		SELECT '' AS PROXYHOST, '' AS PROXYPORT, '' AS PROXYTYPE, 
			0 AS PROXYTIMEOUT	
		FROM (SELECT COUNT(*) AS NUMBER FROM DB2EXT.PROXYINFORMATION)
		     AS COUNTROW
		WHERE COUNTROW.NUMBER = 0 OR
		      NOPROXY = SYSFUN.UCASE('NOPROXY')
		UNION
		SELECT PROXYHOST, PROXYPORT, PROXYTYPE, PROXYTIMEOUT
		FROM   DB2EXT.PROXYINFORMATION
		WHERE  NOPROXY <> SYSFUN.UCASE('NOPROXY'))
	SELECT DB2EXT.GETDATALINKCONTENT(SYSIBM.DLURLSCHEME(DATALINKVALUE),
					 SYSIBM.DLURLSERVER(DATALINKVALUE),
------------------------------------------------------------------------
-- Change this parameter to:
-- SYSIBM.dlurlpathonly(dataLinkValue)
-- as long as DataLink behaviour is not changed
					 SYSIBM.DLURLPATH(DATALINKVALUE),
------------------------------------------------------------------------
					 SYSIBM.DLURLCOMPLETE(DATALINKVALUE),
					 TT.PROXYHOST,
					 TT.PROXYPORT,
					 TT.PROXYTYPE,
					 TIMEOUT
					)
	FROM TEMPTABLE TT;


------------------------------------------------------------------------
-- Highlight Frontend Function for
-- text type DATALINK
------------------------------------------------------------------------

--CREATE FUNCTION DB2EXT.HIGHLIGHT
--        (
--                DOCUMENTCONTENT    DATALINK,
--                HITINFORMATION     BLOB(20K),
--                HITPROCINFORMATION VARCHAR(1024)
--        )
--        RETURNS CLOB(200K)
--        SPECIFIC CTE4D5
--        RETURN
--         DB2EXT.HIGHLIGHT( DB2EXT.GETDATALINKCONTENT(DOCUMENTCONTENT),
--                            HITINFORMATION,
--                            HITPROCINFORMATION)
--;

--GRANT EXECUTE ON FUNCTION DB2EXT.HIGHLIGHT (
--  DATALINK, BLOB(20K), VARCHAR(1024))
--TO PUBLIC;

------------------------------------------------------------------------

